==> flutter_file_view-0.1.1.tar.gz: lib/src/file_network_view.dart <==
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import '../flutter_file_view.dart';

///
/// Describe: File network view component
///
/// @Author: LiWeNHuI
/// @Date: 2021/9/14
///

class FileNetworkView extends StatefulWidget {
  const FileNetworkView({
    Key? key,
    required this.fileShowName,
    required this.fileType,
    required this.downloadUrl,
    required this.downloadPath,
    required this.onViewPressed,
    this.fileNameStyle,
    this.fileSizeStyle,
    this.downloadTitle,
    this.viewTitle,
    this.btnTitleColor,
    this.btnBgColor,
    this.borderSide,
    this.cornerRadius,
  }) : super(key: key);

  ///
  /// The name of the file displayed on the page
  ///
  final String fileShowName;

  ///
  /// The type of file
  ///
  final String fileType;

  ///
  /// File link to download
  ///
  final String downloadUrl;

  ///
  /// It is used to determine whether the file can be downloaded
  /// and the storage address of the downloaded file
  ///
  final String downloadPath;

  ///
  /// File viewing function
  ///
  final VoidCallback onViewPressed;

  ///
  /// Font type of [fileShowName]
  ///
  final TextStyle? fileNameStyle;

  ///
  /// Font type of fileSize
  ///
  final TextStyle? fileSizeStyle;

  ///
  /// Button title when downloadable
  ///
  final String? downloadTitle;

  ///
  /// Button title when viewable
  ///
  final String? viewTitle;

  final Color? btnTitleColor;
  final Color? btnBgColor;
  final BorderSide? borderSide;
  final double? cornerRadius;

  _FileNetworkViewState createState() => _FileNetworkViewState();
}

class _FileNetworkViewState extends State<FileNetworkView> {
  /// Does it support downloading
  bool isDownload = true;

  /// Show download progress bar
  bool isShowProgress = false;

  /// Download progress
  double progressValue = 0.0;

  /// File size
  String fileSize = '计算中...';

  @override
  void initState() {
    super.initState();

    WidgetsBinding.instance!.addPostFrameCallback((callback) {
      isDownloadFile();
      getNetworkFileSize();
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        brightness: Brightness.light,
        backgroundColor: Colors.transparent,
        elevation: 0,
        iconTheme: IconThemeData(color: Colors.black),
      ),
      body: _buildBodyWidget(),
    );
  }

  Widget _buildBodyWidget() {
    return Column(
      children: [
        Expanded(
          child: Center(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: _buildTopWidget(),
            ),
          ),
        ),
        Expanded(
          child: Center(
            child: isShowProgress ? _buildProgress() : _buildButtonWidget(),
          ),
        ),
      ],
    );
  }

  List<Widget> _buildTopWidget() {
    return <Widget>[
      Image.asset(
        fileTypeImage,
        package: 'flutter_file_view',
        width: 48,
        height: 48,
      ),
      Container(
        margin: EdgeInsets.symmetric(vertical: 40.0),
        child: Text(
          widget.fileShowName,
          style: widget.fileNameStyle ??
              TextStyle(
                color: const Color(0xFF333333),
                fontWeight: FontWeight.bold,
              ),
        ),
      ),
      Text(
        fileSize,
        style:
            widget.fileSizeStyle ?? TextStyle(color: const Color(0xFF333333)),
      ),
    ];
  }

  ///
  /// Download Button
  ///
  Widget _buildButtonWidget() {
    double screenWidth = MediaQuery.of(context).size.width;
    double defaultWidth = screenWidth / 3.5;
    defaultWidth = defaultWidth < 120 ? 120 : defaultWidth;
    double defaultHeight = defaultWidth / 3;
    defaultHeight = defaultHeight < 40 ? 40 : defaultHeight;

    return ElevatedButton(
      onPressed: () async {
        if (isDownload) {
          await _download();
        } else {
          widget.onViewPressed();
        }
      },
      child: Text(btnName),
      style: ButtonStyle(
        // 设置按钮上字体与图标的颜色
        foregroundColor: MaterialStateProperty.resolveWith((states) {
          return widget.btnTitleColor ?? Colors.white;
        }),
        // 背景颜色
        backgroundColor: MaterialStateProperty.resolveWith((states) {
          // 当按钮无法点击时 设置背景色
          if (states.contains(MaterialState.disabled)) {
            return Colors.grey[350];
          } else {
            return widget.btnBgColor ?? Theme.of(context).primaryColor;
          }
        }),
        // 设置水波纹颜色
        overlayColor: MaterialStateProperty.all(Colors.black26),
        // 设置阴影
        elevation: MaterialStateProperty.all(0),
        //设置按钮的大小
        minimumSize:
            MaterialStateProperty.all(Size(defaultWidth, defaultHeight)),
        //设置边框
        side: widget.borderSide == null
            ? null
            : MaterialStateProperty.all(widget.borderSide),
      ),
    );
  }

  ///
  /// Download Progress
  ///
  Widget _buildProgress() {
    return SizedBox(
      width: 48.0,
      height: 48.0,
      child: CircularProgressIndicator(
        value: progressValue,
        strokeWidth: 8.0,
        backgroundColor: Theme.of(context).primaryColor,
        valueColor: AlwaysStoppedAnimation<Color>(Colors.tealAccent),
      ),
    );
  }

  ///
  /// Download File
  ///
  Future<void> _download() async {
    String url = widget.downloadUrl;
    String path = widget.downloadPath;

    setState(() {
      if (mounted) isShowProgress = true;
    });

    DownloadStatus status = await DownloadUtil.downloadFile(url, path,
        onReceiveProgress: (count, total) async {
      setState(() {
        if (mounted) progressValue = count / total;
      });
    });

    setState(() {
      if (mounted) {
        if (status == DownloadStatus.success) {
          isDownload = false;
        } else {
          isDownload = true;
        }

        isShowProgress = false;
        progressValue = 0.0;
      }
    });
  }

  ///
  /// Judge whether the file can be downloaded
  ///
  void isDownloadFile() async {
    bool flag = await File(widget.downloadPath).exists();
    setState(() {
      if (mounted) isDownload = !flag;
    });
  }

  ///
  /// Get network file size
  ///
  void getNetworkFileSize() async {
    String size = await FlutterFileView.getFileSize(widget.downloadUrl);
    setState(() {
      if (mounted) fileSize = size;
    });
  }

  ///
  /// Obtain the text displayed by the button
  /// by judging whether it can be downloaded
  ///
  String get btnName {
    return isDownload
        ? widget.downloadTitle ?? '文件下载'
        : widget.viewTitle ?? '文件查看';
  }

  ///
  /// Picture displayed by file type
  ///
  String get fileTypeImage {
    String type = 'assets/images/';
    switch (widget.fileType) {
      case 'doc':
      case 'docx':
        type += 'ic_file_doc.png';
        break;
      case 'xls':
      case 'xlsx':
        type += 'ic_file_xls.png';
        break;
      case 'ppt':
      case 'pptx':
        type += 'ic_file_ppt.png';
        break;
      case 'txt':
        type += 'ic_file_txt.png';
        break;
      case 'pdf':
        type += 'ic_file_pdf.png';
        break;
      case 'zip':
      case 'rar':
      case '7z':
        type += 'ic_file_zip.png';
        break;
      case 'mp4':
      case 'mov':
      case 'avi':
        type += 'ic_file_video.png';
        break;
      case 'mp3':
      case 'wav':
        type += 'ic_file_music.png';
        break;
      default:
        type += 'ic_file_other.png';
        break;
    }

    return type;
  }
}

==> flutter_file_view-0.1.4.tar.gz: lib/src/file_network_view.dart <==
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import '../flutter_file_view.dart';

///
/// Describe: File network view component
///
/// @Author: LiWeNHuI
/// @Date: 2021/9/14
///

class FileNetworkView extends StatefulWidget {
  const FileNetworkView({
    Key? key,
    required this.fileShowName,
    required this.fileType,
    required this.downloadUrl,
    required this.downloadPath,
    required this.onViewPressed,
    this.fileNameStyle,
    this.fileSizeStyle,
    this.downloadTitle,
    this.viewTitle,
    this.btnTitleColor,
    this.btnBgColor,
    this.borderSide,
    this.cornerRadius,
  }) : super(key: key);

  ///
  /// The name of the file displayed on the page
  ///
  final String fileShowName;

  ///
  /// The type of file
  ///
  final String fileType;

  ///
  /// File link to download
  ///
  final String downloadUrl;

  ///
  /// It is used to determine whether the file can be downloaded
  /// and the storage address of the downloaded file
  ///
  final String downloadPath;

  ///
  /// File viewing function
  ///
  final VoidCallback onViewPressed;

  ///
  /// Font type of [fileShowName]
  ///
  final TextStyle? fileNameStyle;

  ///
  /// Font type of fileSize
  ///
  final TextStyle? fileSizeStyle;

  ///
  /// Button title when downloadable
  ///
  final String? downloadTitle;

  ///
  /// Button title when viewable
  ///
  final String? viewTitle;

  final Color? btnTitleColor;
  final Color? btnBgColor;
  final BorderSide? borderSide;
  final double? cornerRadius;

  _FileNetworkViewState createState() => _FileNetworkViewState();
}

class _FileNetworkViewState extends State<FileNetworkView> {
  /// Does it support downloading
  bool isDownload = true;

  /// Show download progress bar
  bool isShowProgress = false;

  /// Download progress
  double progressValue = 0.0;

  /// File size
  String fileSize = '计算中...';

  @override
  void initState() {
    super.initState();

    WidgetsBinding.instance!.addPostFrameCallback((callback) {
      isDownloadFile();
      getNetworkFileSize();
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        systemOverlayStyle: SystemUiOverlayStyle.dark,
        backgroundColor: Colors.transparent,
        elevation: 0,
        iconTheme: IconThemeData(color: Colors.black),
      ),
      body: _buildBodyWidget(),
    );
  }

  Widget _buildBodyWidget() {
    return Column(
      children: [
        Expanded(
          child: Center(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: _buildTopWidget(),
            ),
          ),
        ),
        Expanded(
          child: Center(
            child: isShowProgress ? _buildProgress() : _buildButtonWidget(),
          ),
        ),
      ],
    );
  }

  List<Widget> _buildTopWidget() {
    return <Widget>[
      Image.asset(
        fileTypeImage,
        package: 'flutter_file_view',
        width: 48,
        height: 48,
      ),
      Container(
        margin: EdgeInsets.symmetric(vertical: 40.0, horizontal: 20.0),
        child: Text(
          widget.fileShowName,
          style: widget.fileNameStyle ??
              TextStyle(
                color: const Color(0xFF333333),
                fontWeight: FontWeight.bold,
              ),
        ),
      ),
      Text(
        fileSize,
        style:
            widget.fileSizeStyle ?? TextStyle(color: const Color(0xFF333333)),
      ),
    ];
  }

  ///
  /// Download Button
  ///
  Widget _buildButtonWidget() {
    double screenWidth = MediaQuery.of(context).size.width;
    double defaultWidth = screenWidth / 3.5;
    defaultWidth = defaultWidth < 120 ? 120 : defaultWidth;
    double defaultHeight = defaultWidth / 3;
    defaultHeight = defaultHeight < 40 ? 40 : defaultHeight;

    return ElevatedButton(
      onPressed: () async {
        if (isDownload) {
          await _download();
        } else {
          widget.onViewPressed();
        }
      },
      child: Text(btnName),
      style: ButtonStyle(
        // 设置按钮上字体与图标的颜色
        foregroundColor: MaterialStateProperty.resolveWith((states) {
          return widget.btnTitleColor ?? Colors.white;
        }),
        // 背景颜色
        backgroundColor: MaterialStateProperty.resolveWith((states) {
          // 当按钮无法点击时 设置背景色
          if (states.contains(MaterialState.disabled)) {
            return Colors.grey[350];
          } else {
            return widget.btnBgColor ?? Theme.of(context).primaryColor;
          }
        }),
        // 设置水波纹颜色
        overlayColor: MaterialStateProperty.all(Colors.black26),
        // 设置阴影
        elevation: MaterialStateProperty.all(0),
        //设置按钮的大小
        minimumSize:
            MaterialStateProperty.all(Size(defaultWidth, defaultHeight)),
        //设置边框
        side: widget.borderSide == null
            ? null
            : MaterialStateProperty.all(widget.borderSide),
      ),
    );
  }

  ///
  /// Download Progress
  ///
  Widget _buildProgress() {
    return SizedBox(
      width: 48.0,
      height: 48.0,
      child: CircularProgressIndicator(
        value: progressValue,
        strokeWidth: 8.0,
        backgroundColor: Theme.of(context).primaryColor,
        valueColor: AlwaysStoppedAnimation<Color>(Colors.tealAccent),
      ),
    );
  }

  ///
  /// Download File
  ///
  Future<void> _download() async {
    String url = widget.downloadUrl;
    String path = widget.downloadPath;

    setState(() {
      if (mounted) isShowProgress = true;
    });

    DownloadStatus status = await DownloadUtil.downloadFile(
      url,
      path,
      onReceiveProgress: (count, total) async {
        setState(() {
          if (mounted) progressValue = count / total;
        });
      },
    );

    setState(() {
      if (mounted) {
        if (status == DownloadStatus.success) {
          isDownload = false;
        } else {
          isDownload = true;
        }

        isShowProgress = false;
        progressValue = 0.0;
      }
    });
  }

  ///
  /// Judge whether the file can be downloaded
  ///
  void isDownloadFile() async {
    bool flag = await File(widget.downloadPath).exists();
    setState(() {
      if (mounted) isDownload = !flag;
    });
  }

  ///
  /// Get network file size
  ///
  void getNetworkFileSize() async {
    String size = await FlutterFileView.getFileSize(widget.downloadUrl);
    setState(() {
      if (mounted) fileSize = size;
    });
  }

  ///
  /// Obtain the text displayed by the button
  /// by judging whether it can be downloaded
  ///
  String get btnName {
    return isDownload
        ? widget.downloadTitle ?? '文件下载'
        : widget.viewTitle ?? '文件查看';
  }

  ///
  /// Picture displayed by file type
  ///
  String get fileTypeImage {
    String type = 'assets/images/';
    switch (widget.fileType) {
      case 'doc':
      case 'docx':
        type += 'ic_file_doc.png';
        break;
      case 'xls':
      case 'xlsx':
        type += 'ic_file_xls.png';
        break;
      case 'ppt':
      case 'pptx':
        type += 'ic_file_ppt.png';
        break;
      case 'txt':
        type += 'ic_file_txt.png';
        break;
      case 'pdf':
        type += 'ic_file_pdf.png';
        break;
      case 'zip':
      case 'rar':
      case '7z':
        type += 'ic_file_zip.png';
        break;
      case 'mp4':
      case 'mov':
      case 'avi':
        type += 'ic_file_video.png';
        break;
      case 'mp3':
      case 'wav':
        type += 'ic_file_music.png';
        break;
      default:
        type += 'ic_file_other.png';
        break;
    }

    return type;
  }
}
